.. Open Debates documentation master file, created by
   sphinx-quickstart on Fri Jan  8 18:31:50 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

:github_url:

============
Open Debates
============

This is the documentation of **Open Debates** for Discord.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   License <license>
   Authors <authors>
   Contribution Guidelines <contributing>
   Installation <installation/index>
   User Manual <manual/index>
   Module Reference <api/modules>



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
